****************************Ministerio de Hacienda*********************************
************************** Sesin 10 de Enero 2011*********************************

clear all 
set more off
pause on

*set seed 3223

** Primero generamos una muestra de 1000 observaciones con errores que se distribuyen normal
** y los siguientes valores para los parametros alpha y beta del modelo bsico. 

scalar alpha   = 0.2
scalar varphi  = 0.2
scalar beta    = 0.7
 
set obs 100000 

* Generamos los errores de distribuciones normales (0,1) de manera aleatoria

gen double u1= rnormal()
gen double u0= rnormal()

* Adems generamos un variable que es observable que se distribuye N(1,3)

gen x = 1 + rnormal()*3

* Generamos las variables de interes

gen y1 =  beta*x + varphi + u1 
gen y0 =  beta*x + u0 

* Resumen de la variable de interes 

sum y1 y0 

* Como tenemos el factual y el contrafactual para cada individuo podemos generar
* el ATE del tratamiento solo tomando la diferencia de las medias. 

sum y1 
scalar y1_mean=r(mean)
sum y0 
scalar y0_mean=r(mean)
scalar treatment = y1_mean - y0_mean
di treatment 

** Ahora generamos una regla de seleccin en el cual los individuos eligen el ser o no tratados de
** de acuerdo al modelo de ganancias. 

gen dif= y1 - y0 
gen D=1 if dif>=0 
replace D=0 if D==. 

* Con la regla de seleccin lista podemos ver los resultados para cada persona 

gen y1_obs = y1 if D==1 
gen y0_obs = y0 if D==0 
egen y0_sel=mean(y0_obs)
egen y1_sel=mean(y1_obs)
gen treat_sel=y1_sel - y0_sel
di treat_sel

* Ahora generamos la variable de interes de acuerdo a la regla de seleccin 
* asumiendo que solo vemos si es tratado o no, y no ambos escenarios para 
* una misma persona. 

gen y=y1*D + (1-D)*y0

** OLS

* Estimamos por OLS el parametro de interes usando una variable binaria la cual 
* indica si esta tratado o no, controlando por observables y usando errores robustos. 

reg y x D, robust

pause

** Experimentos 
** Generamos una distribucion uniforme (0,1) para asignar el tratamiento 

gen treat_aux=runiform()
gen treat=round(treat_aux)

table treat , c(mean y)

** Matching 

*Como vemos en la siguiente tabla las caracteristicas de los individuos entre el grupo
*de tratamiento y de control difieren. 

table D, c(mean x)

*Estimamos la probabilidad de ser tratado condicional a las caracteristicas observables. 

probit D x 
predict score_aux
tw(hist score_aux if D==1)
pause
tw(hist score_aux if D==0)
pause

* Usamos el comando que trae incorporado Stata

psmatch2 D x, outcome(y)

** IV 

*Generamos un instrumento el cual es una variable no correlacionada con los observables pero 
*sin con la probabilidad de ser tratado 

drop D y dif
gen z = rnormal()*4
gen dif= y1 - y0 - z
gen D=1 if dif>=0 
replace D=0 if D==.
gen y=y1*D + (1-D)*y0

reg y x D, robust
ivreg y x (D=z), robust


